@@ -17,7 +17,7 @@ class App(Base):
       self._socket = sock.makefile()
       Helper.write_hash_to_file({"language":"python", "name":self._name, "flow_type":"app", "multilang_version":VERSION}, self._socket)
 
-  def source(self, name=None, matches=None, options={}, emits=None, end_cycle_policy="null_emit", begin_cycle=None, next_tuple=None):
+  def source(self, name=None, matches=None, options={}, emits=None, end_cycle_policy="null_emit", prepare=None, begin_cycle=None, next_tuple=None):
     op = OperationHandler(self, Stream)
     streams = op.build_multilang_operation("source", name, matches, options, emits, end_cycle_policy, begin_cycle, next_tuple)\
                        .add_operation_properties_to_info("name", "type")\
