@@ -27,7 +27,7 @@ class Stream:
                 .get_output_streams()
     return streams
 
-  def group_by(self, name=None, emits=None, fields=None, begin_group=None, aggregate=None, end_group=None, parallelism=None):
+  def group_by(self, name=None, emits=None, fields=None, prepare=None, begin_group=None, aggregate=None, end_group=None, parallelism=None):
     op = OperationHandler(self._app, self.__class__)
     streams = op.build_multilang_operation("group_by", name, emits, fields, begin_group, aggregate, end_group, parallelism)\
                 .add_operation_properties_to_info("name", "type", "group_by")\
@@ -61,7 +61,7 @@ class Stream:
     return streams
 
   def loop_back(self, operation):
-    Helper.check_loop_back(operation, self._app._nodes)
+    Helper.check_loop_back(self, operation, self._app._nodes)
     Helper.write_arc_to_file({"name" : self._name, "origin" : self._previous_node_name, "dest" : operation, "loop_back" : 1}, self._app._socket)
     return self
 
